@@ -6,6 +6,7 @@ from django.conf import settings
 from tcell_agent.global_state import has_agent_started, set_agent_has_started, update_default_charset
 
 from tcell_agent.agent import TCellAgent
+from tcell_agent.config.configuration import get_config
 from tcell_agent.instrumentation.decorators import catches_generic_exception
 from tcell_agent.instrumentation.djangoinst.settings import send_django_setting_events
 from tcell_agent.events.server_agent_framework_event import ServerAgentFrameworkEvent
@@ -20,10 +21,11 @@ def start_agent():
         if has_agent_started():
             return False
 
-        set_agent_has_started()
-        TCellAgent.startup()
+        if TCellAgent.startup():
+            set_agent_has_started()
+            return True
 
-    return True
+    return False
 
 
 @catches_generic_exception(__name__, "Error checking agent startup")
@@ -34,7 +36,7 @@ def ensure_agent_started():
     if settings.DEFAULT_CHARSET:
         update_default_charset(settings.DEFAULT_CHARSET)
 
-    if start_agent():
+    if get_config().enabled and start_agent():
         sade = ServerAgentFrameworkEvent("Django", get_version())
         TCellAgent.send(sade)
         send_django_setting_events()
