@@ -5,11 +5,10 @@ from tcell_agent.events.server_agent_framework_event import ServerAgentFramework
 
 @catches_generic_exception(__name__, "Error starting agent")
 def start_agent():
-    TCellAgent.startup()
+    if TCellAgent.startup():
+        from tcell_agent.instrumentation.flaskinst.routes import report_routes
+        report_routes()
 
-    from tcell_agent.instrumentation.flaskinst.routes import report_routes
-    report_routes()
-
-    from flask import __version__
-    sade = ServerAgentFrameworkEvent("Flask", __version__)
-    TCellAgent.send(sade)
+        from flask import __version__
+        sade = ServerAgentFrameworkEvent("Flask", __version__)
+        TCellAgent.send(sade)
