@@ -1,4 +1,5 @@
 from tcell_agent.rust.native_callers import NativeCaller
+from tcell_agent.rust.models.agent_config import AgentConfig
 from tcell_agent.rust.native_library import get_native_lib
 
 
@@ -22,16 +23,8 @@ def test_event_sender(config, events, version, uuid):
     return []
 
 
-def test_policies(config):
-    if get_native_lib():
-        caller = NativeCaller(native_method_name="test_policies",
-                              bytes_to_allocate=1024 * 8)
-        caller.append_parameter({
-            "app_id":        config.app_id,
-            "api_key":       config.api_key,
-            "tcell_api_url": config.tcell_api_url
-        })
-        response = caller.execute()
-        return response.get_errors()
-
-    return []
+def test_agent():
+    caller = NativeCaller(native_method_name="test_agent",
+                          bytes_to_allocate=1028 * 8)
+    caller.append_parameter(AgentConfig())
+    caller.execute()
