@@ -18,7 +18,7 @@ def get_linux_variant():
     return ""
 
 
-version = "4.18.0"
+version = "6.2.1"
 prefix = {"win32": ""}.get(sys.platform, "lib")
 extension = {"darwin": ".dylib", "win32": ".dll"}.get(sys.platform, ".so")
 variant = get_linux_variant()
@@ -91,8 +91,8 @@ def load_native_lib():
     _NATIVE_LIB.test_policies.argtypes = [c_char_p, c_size_t, POINTER(c_uint8), c_size_t]
     _NATIVE_LIB.test_policies.restype = c_int
 
-    _NATIVE_LIB.set_extra_diagnostics_config.argtypes = [c_void_p, c_char_p, c_size_t, POINTER(c_uint8), c_size_t]
-    _NATIVE_LIB.set_extra_diagnostics_config.restype = c_int
-
     _NATIVE_LIB.suspicious_quick_check_apply.argtypes = [c_void_p, c_char_p, c_size_t]
     _NATIVE_LIB.suspicious_quick_check_apply.restype = c_int
+
+    _NATIVE_LIB.test_agent.argtypes = [c_char_p, c_size_t, POINTER(c_uint8), c_size_t]
+    _NATIVE_LIB.test_agent.resttype = c_int
